@@ -32,12 +32,15 @@ import org.gcube.portlets.user.td.gwtservice.shared.tr.metadata.TRMetadata;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.open.TDOpenSession;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.paging.CodelistPagingLoadConfig;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.paging.CodelistPagingLoadResult;
+import org.gcube.portlets.user.td.gwtservice.shared.tr.table.ChangeTableTypeMonitor;
+import org.gcube.portlets.user.td.gwtservice.shared.tr.table.ChangeTableTypeSession;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.table.metadata.TabMetadata;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.type.Agencies;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.type.Codelist;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.type.Dataset;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 
+import com.google.gwt.user.client.rpc.AsyncCallback;
 import com.google.gwt.user.client.rpc.RemoteService;
 import com.google.gwt.user.client.rpc.RemoteServiceRelativePath;
 
@@ -114,6 +117,15 @@ public interface TDGWTService extends RemoteService {
 	 */
 	public TableData getLastTable(TRId trId) throws TDGWTServiceException;
 
+	/**
+	 * Return Table
+	 * 
+	 * @param trId
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public TableData getTable(TRId trId) throws TDGWTServiceException;
+
 	/**
 	 * Return Metadata of Table
 	 * 
@@ -145,7 +157,6 @@ public interface TDGWTService extends RemoteService {
 	public ArrayList<TabResource> getTabularResources()
 			throws TDGWTServiceException;
 
-	
 	/**
 	 * Initialize Codelists Paging Loader
 	 * 
@@ -154,7 +165,7 @@ public interface TDGWTService extends RemoteService {
 	public void setCodelistsPagingLoader() throws TDGWTServiceException;
 
 	/**
-	 * Retrieves a portion of Codelists 
+	 * Retrieves a portion of Codelists
 	 * 
 	 * @param codelistPagingLoadConfig
 	 * @return
@@ -371,7 +382,28 @@ public interface TDGWTService extends RemoteService {
 	public void startSDMXExport(SDMXExportSession exportSession)
 			throws TDGWTServiceException;
 
-	//Column Operation 
+	// Change Table Type
+	/**
+	 * Get Operation Monitor during the Change Table Type operation
+	 * 
+	 * 
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public ChangeTableTypeMonitor getChangeTableTypeMonitor()
+			throws TDGWTServiceException;
+
+	/**
+	 * Start change table type
+	 * 
+	 * @param labelColumnSession
+	 * @throws TDGWTServiceException
+	 */
+	public void startChangeTableType(
+			ChangeTableTypeSession changeTableTypeSession)
+			throws TDGWTServiceException;
+
+	// Column Operation
 
 	/**
 	 * Get Operation Monitor during the Change Column Type operation
@@ -392,7 +424,6 @@ public interface TDGWTService extends RemoteService {
 			ChangeColumnTypeSession changeColumnTypeSession)
 			throws TDGWTServiceException;
 
-
 	/**
 	 * Get Operation Monitor during the Delete Column operation
 	 * 
@@ -404,17 +435,15 @@ public interface TDGWTService extends RemoteService {
 			throws TDGWTServiceException;
 
 	/**
-	 * Start delete column 
+	 * Start delete column
 	 * 
 	 * 
 	 * @param deleteColumnSession
 	 * @throws TDGWTServiceException
 	 */
-	public void startDeleteColumn(
-			DeleteColumnSession deleteColumnSession)
+	public void startDeleteColumn(DeleteColumnSession deleteColumnSession)
 			throws TDGWTServiceException;
 
-	
 	/**
 	 * Get Operation Monitor during the Change the Column Label operation
 	 * 
@@ -431,11 +460,7 @@ public interface TDGWTService extends RemoteService {
 	 * @param labelColumnSession
 	 * @throws TDGWTServiceException
 	 */
-	public void startLabelColumn(
-			LabelColumnSession labelColumnSession)
+	public void startLabelColumn(LabelColumnSession labelColumnSession)
 			throws TDGWTServiceException;
 
-	
-	
-	
 }
